package com.huiju.estateagents.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaRaise;
import com.huiju.estateagents.entity.TaRaiseRecord;
import com.huiju.estateagents.mapper.TaRaiseMapper;
import com.huiju.estateagents.mapper.TaRaiseRecordMapper;
import com.huiju.estateagents.service.ITaRaiseService;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * <p>
 * 认筹表  服务实现类
 * </p>
 *
 * @author jobob
 * @since 2020-02-26
 */
@Service
public class TaRaiseServiceImpl extends ServiceImpl<TaRaiseMapper, TaRaise> implements ITaRaiseService {

    private Logger logger = LoggerFactory.getLogger(TaRaiseServiceImpl.class);

    @Autowired
    private TaRaiseRecordMapper taRaiseRecordMapper;

    @Override
    public ResponseBean batchDelete(List<TaRaise> taRaiseList, Integer orgId) {
        logger.info("TaRaiseServiceImpl.batchDelete 接收参数：list:{},orgId:{}", JSONObject.toJSONString(taRaiseList), orgId);

        ResponseBean responseBean = new ResponseBean();
        // 校验参数
        if (CollectionUtils.isEmpty(taRaiseList)) {
            responseBean.addError("参数错误");
            return responseBean;
        }

        for (TaRaise tr : taRaiseList) {

            // 校验销售批次下是否有认筹记录
            QueryWrapper<TaRaiseRecord> taRaiseRecordQueryWrapper = new QueryWrapper<>();
            taRaiseRecordQueryWrapper.eq("org_id", orgId);
//            taRaiseRecordQueryWrapper.eq("raise_id", tr.getRaiseId());
            taRaiseRecordQueryWrapper.eq("sales_batch_id", tr.getSalesBatchId());
            taRaiseRecordQueryWrapper.eq("status", 1);
            List<TaRaiseRecord> list = taRaiseRecordMapper.selectList(taRaiseRecordQueryWrapper);
            if (CollectionUtils.isNotEmpty(list)) {
                responseBean.addError(String.format("销售批次%s下已有认筹记录，不可删除", tr.getSalesBatchId()));
                return responseBean;
            }
        }

        taRaiseList.stream().forEach(record -> {
            record.setStatus(-1);
        });

        if (updateBatchById(taRaiseList)) {
            responseBean.addError("success");
        } else {
            responseBean.addError("fail");
        }
        return responseBean;
    }
}
